<?php

require_once 'connector.php';

function generateVerificationToken() {
  // Use a secure random number generator function
  $token = bin2hex(random_bytes(32));
  return $token;
}


function sendWelcomeEmail($email, $verificationToken) {
    $to = $email;
    $subject = "Welcome to SET Lotto!";
    $verificationLink = "https://www.setlottonig.com/dev/v6/verify?email=" . $email . "&token=" . $verificationToken;
    $message = "
        <!DOCTYPE html>
        <html>
        <head>
            <title>Welcome to SET Lotto</title>
            <style>
		    body {
		      font-family: sans-serif;
		      margin: 0;
		      padding: 0;
		    }
		    .container {
		      padding: 20px;
		      max-width: 600px;
		      margin: 0 auto;
		      background-color: #f5f5f5;
		    }
		    .header {
		      text-align: center;
		    }
		    .logo {
		      width: 150px;
		      height: auto;
		      margin: 10px auto;
		    }
		    .content {
		      padding: 20px;
		    }
		    .cta {
		      text-align: center;
		      margin-top: 20px;
		    }
		    a {
		      background-color: #2ecc71;
		      color: white;
		      padding: 10px 20px;
		      border-radius: 5px;
		      text-decoration: none;
		    }
		    .footer {
		      text-align: center;
		      font-size: 12px;
		      padding-top: 20px;
		      color: #999;
		    }
	</style>
        </head>
        <body>
	  <div class='container'>
	    <header class='header'>
	      <img src='https://setlottonig.com/assets/img/logo/white_logo.png' alt='SET Lotto Logo' class='logo'>
	      <h1>Welcome to SET Lotto, $email!</h1>
	    </header>
	    <div class='content'>
	      <p>Your SET Lotto account has been successfully created! Now you're just a few clicks away from exciting lottery games and potential wins.</p>
	      <p>Ready to win <b>Big?</b>  Activate your account and start playing, please click the verification link below:</p>
	      <p><a href='$verificationLink'>Activate Your Account</a></p>
	      <p>This link will expire in 24 hours. If you don't verify your account within this timeframe, you'll need to request a new verification link.</p>
</p>
	    </div>
	    <div class='cta'>
	      <a href='https://www.setlottonig.com'>Start Playing Now!</a>
	    </div>
	    <footer class='footer'>
	      <p>Don't forget to check out our latest games and promotions! Reply to this email if you have any questions.</p>
	      <p>Good luck!</p>
	    </footer>
	  </div>
	</body>
	</html>
    ";
    $headers = "MIME-Version: 1.0" . "\r\n";
    $headers .= "Content-type:text/html;charset=UTF-8" . "\r\n";
    $headers .= "From: SET Lotto <noreply@setlottonig.com>";

    mail($to, $subject, $message, $headers);
}


function createUser($email, $dob, $password, $verificationToken) {
  global $pdo;

  // Generate a verification token if none is provided
  //if (empty($verificationToken)) {
   // $verificationToken = generateVerificationToken();
  //}

  // Prepare the SQL statement with placeholders
  $sql = "INSERT INTO users (email, dob, password, verification_token) VALUES (?, ?, ?, ?)";
  $stmt = $pdo->prepare($sql);

  // Hash the password using bcrypt with a cost factor of 10
  $hashed_password = password_hash($password, PASSWORD_BCRYPT, ['cost' => 10]);

  // Bind the values to the prepared statement
  $stmt->bindValue(1, $email);
  $stmt->bindValue(2, $dob);
  $stmt->bindValue(3, $hashed_password);
  $stmt->bindValue(4, $verificationToken);

  // Execute the query
  if ($stmt->execute()) {
    sendWelcomeEmail($email, $verificationToken);
    echo 'success';
    exit;
  } else {
    return false; // Error creating user
  }
}


// Handle POST request
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Validate form data
    $email = $_POST['email'];
    $dob = $_POST['dob'];
    $password = $_POST['password'];
    $password_confirmation = $_POST['password_confirmation'];
    $verificationToken = $_POST['_token'];

    // Basic validation
    if (empty($email) || empty($dob) || empty($password) || empty($password_confirmation)) {
        // Handle validation error
        die('Please fill in all fields.');
    }

    if ($password !== $password_confirmation) {
        // Handle password mismatch error
        die('Passwords do not match.');
    }

    // Create user
    if (createUser($email, $dob, $password, $verificationToken)) {
         // User created successfully
    	echo 'success';

    	// Set a hidden form field or session variable (recommended)
    	$_SESSION['user_created'] = true; // Example using session

        //header("Location: /dev/v6/otp?email=".$email);
    } else {
        // Error creating user
        die('Error creating user.');
    }
}
?>
<!DOCTYPE html>
        <html>
        <head>
            <title>Welcome to SET Lotto</title>
            <style>
            .popup {
	    display: none;
	    position: fixed;
	    top: 50%;
	    left: 50%;
	    transform: translate(-50%, -50%);
	    background-color: #fff;
	    border-radius: 10px;
	    box-shadow: 0px 0px 10px rgba(0, 0, 0, 0.2);
	    padding: 20px;
	    z-index: 9999;
	}
	
	.popup-content {
	    text-align: center;
	}
	
	.button {
	    padding: 10px 20px;
	    background-color: #4CAF50;
	    color: white;
	    border: none;
	    border-radius: 5px;
	    cursor: pointer;
	}
            </style>
        </head>
        <body>
<div id="successPopup" class="popup">
    <div class="popup-content">
        <h2>Account Created Successfully!</h2>
        <p>Please click the button below to log in.</p>
        <button id="loginRedirect" class="button">Log In</button>
    </div>
</div>

<div id="failurePopup" class="popup">
    <div class="popup-content">
        <h2>Account Creation Failed</h2>
        <p>Please try again later or contact support.</p>
        <button id="returnToRegister" class="button">Return to Registration</button>
    </div>
</div><script>
  // Assuming you have jQuery
  $(document).ready(function() {
    // Show success popup and redirect to login
    function showSuccessPopup() {
      $('#successPopup').show();
      $('#loginRedirect').click(function() {
        window.location.href = '/v6/login/';
      });
    }

    // Show failure popup and return to registration
    function showFailurePopup() {
      $('#failurePopup').show();
      $('#returnToRegister').click(function() {
        window.location.href = '/login/register/'; 
      });
    }

    <?php if (isset($_SESSION['user_created'])) { // Check session variable (example) ?>
      showSuccessPopup();
      <?php unset($_SESSION['user_created']); // Clear session variable after use ?>
    <?php } else { ?>
      showFailurePopup();
    <?php } ?>
  });
  </script>
</head>
<body>
<form>
  </form>
<body>
</body>
<html>