<?php
header('Content-Type: application/json');
require_once 'connector.php';


function sendWelcomeEmail($email, $verificationToken, $otp) {
    $to = $email;
    $subject = "Welcome to SET Lotto!";
    $verificationLink = "https://www.setlottonig.com/dev/v6/otp";
    $message = "
        <!DOCTYPE html>
        <html>
        <head>
            <title>Welcome to SET Lotto</title>
            <style>
		    body {
		      font-family: sans-serif;
		      margin: 0;
		      padding: 0;
		    }
		    .container {
		      padding: 20px;
		      max-width: 600px;
		      margin: 0 auto;
		      background-color: #f5f5f5;
		    }
		    .header {
		      text-align: center;
		    }
		    .logo {
		      width: 150px;
		      height: auto;
		      margin: 10px auto;
		    }
		    .content {
		      padding: 20px;
		    }
		    .cta {
		      text-align: center;
		      margin-top: 20px;
		    }
		    a {
		      background-color: #2ecc71;
		      color: white;
		      padding: 10px 20px;
		      border-radius: 5px;
		      text-decoration: none;
		    }
		    .footer {
		      text-align: center;
		      font-size: 12px;
		      padding-top: 20px;
		      color: #999;
		    }
	</style>
        </head>
        <body>
	  <div class='container'>
	    <header class='header'>
	      <img src='https://setlottonig.com/assets/img/logo/white_logo.png' alt='SET Lotto Logo' class='logo'>
	      <h1>Welcome to SET Lotto, $email!</h1>
	    </header>
	    <div class='content'>
	      <p>Your SET Lotto account has been successfully created! Now you're just a few clicks away from exciting lottery games and potential wins.</p>
	      <p>Ready to win <b>Big?</b>  Activate your account and start playing with the One Time Password below:</p>
	      <p>$otp</p>
	      <p><a href='$verificationLink'>Activate Your Account</a></p>
	      <p>This OTP will expire in 24 hours. If you don't verify your account within this timeframe, you'll need to request a new OTP.</p>
</p>
	    </div>
	    <div class='cta'>
	      <a href='https://www.setlottonig.com/dev/v6/play_games'>Start Playing Now!</a>
	    </div>
	    <footer class='footer'>
	      <p>Don't forget to check out our latest games and promotions! Reply to this email if you have any questions.</p>
	      <p>Good luck!</p>
	    </footer>
	  </div>
	</body>
	</html>
    ";
    $headers = "MIME-Version: 1.0" . "\r\n";
    $headers .= "Content-type:text/html;charset=UTF-8" . "\r\n";
    $headers .= "From: SET Lotto <noreply@setlottonig.com>";

    mail($to, $subject, $message, $headers);
}


function createUser($email, $dob, $password, $verificationToken, $otp) {
  global $pdo;
  $currencyid = 10;
  // Validate data here (e.g., required fields, file size, etc.)
    if (empty($email) || empty($dob) || empty($password) || empty($verificationToken)) {
        return ['status' => 'error', 'message' => 'Please fill in all required fields.'];
    }
    
    
$pdo->beginTransaction();

try {

 // Check if email already exists
        $sql = "SELECT COUNT(*) FROM users WHERE email = ?";
        $stmt = $pdo->prepare($sql);
        $stmt->bindValue(1, $email);
        $stmt->execute();
        $count = $stmt->fetchColumn();

        if ($count > 0) {
            $pdo->rollback();
            return (['status' => 501, 'message' => 'Unable to create user... Email already exists']);
        }
        else{
  // Hash the password using bcrypt with a cost factor of 10
  $hashed_password = password_hash($password, PASSWORD_BCRYPT, ['cost' => 10]);
    // Insert into users
    $sql = "INSERT INTO users (email, dob, password, verification_token) VALUES (?, ?, ?, ?)";
    $stmt = $pdo->prepare($sql);
    $stmt->bindValue(1, $email);
    $stmt->bindValue(2, $dob);
    $stmt->bindValue(3, $hashed_password);
    $stmt->bindValue(4, $verificationToken);
    $stmt->execute();
    
    // Get the ID of the newly inserted user
    $sql = "SELECT id FROM users WHERE email = ?";
    $stmt = $pdo->prepare($sql);
    $stmt->bindValue(1, $email);
    $stmt->execute();
    $result = $stmt->fetch(PDO::FETCH_ASSOC);
    $userId = $result['id'];
   
    // Hash the OTP using bcrypt with a cost factor of 10
    $hashed_otp = password_hash($otp, PASSWORD_BCRYPT, ['cost' => 10]);
    // Insert into OTPS
    $sql = "INSERT INTO otps (user_id, otp) VALUES (?, ?)";
    $stmt = $pdo->prepare($sql);
    $stmt->bindValue(1, $userId);
    $stmt->bindValue(2, $hashed_otp );
    $stmt->execute();

    // Insert into profiles
    $sql = "INSERT INTO profiles (user_id) VALUES (?)";
    $stmt = $pdo->prepare($sql);
    $stmt->bindValue(1, $userId);
    $stmt->execute();

    // Insert into b_wallets
    $sql = "INSERT INTO b_wallets (user_id, currency_id) VALUES (?,?)";
    $stmt = $pdo->prepare($sql);
    $stmt->bindValue(1, $userId);
    $stmt->bindValue(2, $currencyid);
    $stmt->execute();

    // Insert into wallets
    $sql = "INSERT INTO wallets (user_id, currency_id) VALUES (?,?)";
    $stmt = $pdo->prepare($sql);
    $stmt->bindValue(1, $userId);
    $stmt->bindValue(2, $currencyid);
    $stmt->execute();

    // Insert into w__wallets
    $sql = "INSERT INTO w__wallets (user_id, currency_id) VALUES (?,?)";
    $stmt = $pdo->prepare($sql);
    $stmt->bindValue(1, $userId);
    $stmt->bindValue(2, $currencyid);
    $stmt->execute();
    

    /* / Insert into loyalty_wallet
    $sql = "INSERT INTO loyalty_wallet (user_id) VALUES (?)";
    $stmt = $pdo->prepare($sql);
    $stmt->execute();*/
    

    $pdo->commit();
    sendWelcomeEmail($email, $verificationToken, $otp);
    return (['status' => 200, 'message' => 'User Created and Email Sent Successfully']);
    }

} catch (PDOException $e) {
    //$pdo->rollBack();
    return (['status' => 500, 'message' => 'Error Creating User: ' . $e->getMessage()]);
}
}


// Handle POST request
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $data = json_decode(file_get_contents('php://input'), true);

    // Validate form data
    $email = $data['email'];
    $dob = $data['dob'];
    $password = $data['password'];
    $password_confirmation = $data['password_confirmation'];
    $verificationToken = $data['token'];
    $otp = rand(100000, 999999);
    
    //$verificationToken = bin2hex(random_bytes(32));

    // Basic validation
    if (empty($email) || empty($dob) || empty($password) || empty($password_confirmation)) {
        // Handle validation error
        die('Please fill in all fields.');
    }    
    // Create User
    $result = createUser($email, $dob, $password, $verificationToken, $otp);
    echo json_encode($result);
}

?>