<?php
require_once 'connector.php';

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $userId = $_POST['userId'];
    $avatar = $_FILES['avatar'];

    // Validate input data
    if (empty($userId) || empty($avatar)) {
        echo json_encode(['status' => 'error', 'message' => 'Please fill in all required fields.']);
        exit;
    }

    $allowedTypes = ['image/jpeg', 'image/jpg', 'image/png', 'image/gif'];
    if (!in_array($avatar['type'], $allowedTypes)) {
        echo json_encode(['status' => 'error', 'message' => 'Invalid file format: Only JPEG, PNG, and GIF are allowed.']);
        exit;
    }

    if ($avatar['size'] > 10000000) { // 10 MB limit
        echo json_encode(['status' => 'error', 'message' => 'Image size exceeds limit (1 MB).']);
        exit;
    }

    // Generate unique filename and upload avatar
    $uploadDir = 'profile/';
    $filePath = $uploadDir . uniqid() . '_' . basename($avatar['name']);

    if (move_uploaded_file($avatar['tmp_name'], $filePath)) {
        try {
            $sql = "UPDATE users SET avatar = :avatar WHERE id = :userId";
            $stmt = $pdo->prepare($sql);
            $stmt->bindValue(':avatar', $filePath);
            $stmt->bindValue(':userId', $userId);
            $stmt->execute();

            echo json_encode(['status' => 'success', 'message' => 'Profile picture uploaded successfully.']);
        } catch (PDOException $e) {
            echo json_encode(['status' => 'error', 'message' => 'Database error: ' . $e->getMessage()]);
        }
    } else {
        echo json_encode(['status' => 'error', 'message' => 'Error uploading file.']);
    }
}