<?php
header('Content-Type: application/json');
require_once 'connector.php';

function updateUser($userId, $firstName, $lastName, $phonenumber, $gender, $state_n) {
    global $pdo;

    // Validate data here (e.g., required fields, file size, etc.)
    if (empty($firstName) || empty($lastName) || empty($phonenumber)) {
        return ['status' => 'error', 'message' => 'Please fill in all required fields.'];
    }

    try {
        // Prepare and execute the SQL query
        $sql = "UPDATE users SET first_name = :firstName, last_name = :lastName, phonenumber = :phonenumber, state_n = :state_n, gender = :gender WHERE id = :userId";
        $stmt = $pdo->prepare($sql);

        $stmt->bindValue(':firstName', $firstName);
        $stmt->bindValue(':lastName', $lastName);
        $stmt->bindValue(':phonenumber', $phonenumber);
        $stmt->bindValue(':state_n', $state_n);
        $stmt->bindValue(':gender', $gender);
        $stmt->bindValue(':userId', $userId);

        if($stmt->execute())
        {
        	return ['status' => 'Success', 'message' => 'User Profile Updated Successfully'];
        }
        else
        {
        	return ['status' => 'Error', 'message' => 'Error Updating User Profile'];
        }
    } catch (PDOException $e) {
        return ['status' => 'error', 'message' => 'Error Updating User: ' . $e->getMessage()];
    }
}

// Handle POST request from form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $data = json_decode(file_get_contents('php://input'), true);

    $userId = $data['userId'];
    $firstName = $data['firstName'];
    $lastName = $data['lastName'];
    $phonenumber = $data['phonenumber'];
    $gender = $data['gender'];
    $state_n = $data['state_n'];

    // Validate data
    if (empty($userId) || empty($firstName) || empty($lastName) || empty($phonenumber)) {
        return ['status' => 'error', 'message' => 'Please fill in all required fields.'];
    }

    // Update User
    $result = updateUser($userId, $firstName, $lastName, $phonenumber, $gender, $state_n);
    echo json_encode($result);
}
?>