<?php
header('Content-Type: application/json');

require_once 'connector.php';

function uploadNINSlip($userId, $image) {

    // Validate input
    if (empty($image)) {
        return ['status' => 'error', 'message' => 'Invalid request: Missing NIN Slip'];
    }

    // Validate image format and size
    $allowedTypes = ['image/jpeg', 'image/jpg', 'image/png', 'image/gif', 'application/pdf'];
    if (!in_array($image['type'], $allowedTypes)) {
        return ['status' => 'error', 'message' => 'Invalid file format: Only JPEG, PNG, GIF, and PDF are allowed'];
    }

    if ($image['size'] > 10000000) { // 10 MB limit
        return ['status' => 'error', 'message' => 'Image size exceeds limit (10 MB)'];
    }

    // Upload new NIN Slip
    $uploadDir = '../storage/app/public/users/';
    $newFilename = uniqid() . '.' . pathinfo($image['name'], PATHINFO_EXTENSION);
    $uploadPath = $uploadDir . $newFilename;

    if (move_uploaded_file($image['tmp_name'], $uploadPath)) {
        return ['status' => 'success', 'message' => 'NIN Slip uploaded successfully', 'filename' => $newFilename];
    } else {
        return ['status' => 'error', 'message' => 'Error uploading NIN Slip'];
    }
}

function verifyNINAndUpdateProfile($userId, $document_nin, $imagePath) {
    global $pdo;

    // Secret key
    $apiKey = 'sk_live_iqg2DK9sh8PYa7GUArlMVF7DGm8wNm5VaAO1qWjjKB89n8bhf6';
    $apiUrl = "https://v2.api.zeeh.africa/nigeria_kyc/lookup_nin";

    $curl = curl_init();

    curl_setopt_array($curl, [
        CURLOPT_URL => $apiUrl,
        CURLOPT_RETURNTRANSFER => true,
        CURLOPT_ENCODING => "",
        CURLOPT_MAXREDIRS => 10,
        CURLOPT_TIMEOUT => 30,
        CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
        CURLOPT_CUSTOMREQUEST => "POST",
        CURLOPT_POSTFIELDS => json_encode([
            'nin' => $document_nin
        ]),
        CURLOPT_HTTPHEADER => [
            "Secret_Key: $apiKey",
            "accept: application/json",
            "content-type: application/json"
        ],
    ]);

    $response = curl_exec($curl);
    curl_close($curl);

    $data = json_decode($response, true);

    if ($data['success'] == 'true') {
        $document_verified = 1;

        try {
            $sql = "UPDATE profiles SET document = :document, document_nin = :document_nin, document_verified = :document_verified WHERE user_id = :userId";
            $stmt = $pdo->prepare($sql);

            $stmt->bindValue(':document', $imagePath);
            $stmt->bindValue(':document_nin', $document_nin);
            $stmt->bindValue(':document_verified', $document_verified);
            $stmt->bindValue(':userId', $userId);

            if ($stmt->execute()) {
                return ['status' => 'success', 'message' => 'User Identity Verified'];
            } else {
                return ['status' => 'error', 'message' => 'Error Verifying User'];
            }
        } catch (PDOException $e) {
            return ['status' => 'error', 'message' => 'Error Verifying User: ' . $e->getMessage()];
        }
    } else {
        return ['status' => 'error', 'message' => $data['message']];
    }
}

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $data = json_decode(file_get_contents('php://input'), true);

    $userId = $data['userId'];
    $document_nin = $data['document_nin'];
    $image = $_FILES['avatar'];

    if (empty($userId) || empty($document_nin) || empty($image)) {
        return ['status' => 'error', 'message' => 'Please fill in all required fields.'];
    }

    $uploadResult = uploadNINSlip($userId, $image);
    if ($uploadResult['status'] !== 'success') {
        return $uploadResult;
    }

    $imagePath = $uploadResult['filename'];

    $verifyResult = verifyNINAndUpdateProfile($userId, $document_nin, $imagePath);
    echo json_encode($verifyResult);
}