<?php
require_once 'connector.php';

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
  $userId = $_POST['userId'];
  $document_nin = $_POST['document_nin'];
  $avatar = $_FILES['avatar'];

  // Validate file and other fields
  if (empty($userId) || empty($document_nin) || empty($avatar)) {
    echo json_encode(['status' => 500, 'message' => 'Please fill in all required fields.']);
    exit;
  }
  
  
    // Validate image format and size
    $allowedTypes = ['image/jpeg', 'image/jpg', 'image/png', 'image/gif', 'application/pdf'];
    if (!in_array($avatar['type'], $allowedTypes)) {
        return ['status' => 500, 'message' => 'Invalid file format: Only JPEG, PNG, GIF, and PDF are allowed'];
    }

    if ($avatar['size'] > 10000000) { // 10 MB limit
        return ['status' => 500, 'message' => 'Image size exceeds limit (10 MB)'];
    }
  

  // Upload the avatar file
  $uploadDir = 'uploads/';
  $filePath = $uploadDir . uniqid() . '_' . basename($avatar['name']);

  if (move_uploaded_file($avatar['tmp_name'], $filePath)) {
    // Verify NIN using Zeeh Africa API
    $verificationData = verifyNIN($document_nin);

	//$verificationData = json_decode($response, true);
	if ($verificationData['statusCode'] === 200 && $verificationData['response_code'] === '00') {
 
    //if (!empty($verificationData['data']['lastName'])) {
      // Update user profile with verified information and file path
      $updateResult = updateUserProfile($userId, $document_nin, $filePath, $verificationData);

      if ($updateResult['status'] === 200) {
        echo json_encode(['status' => 'success', 'message' => 'User Identity Verified']);
      } else {
        echo json_encode(['status' => 500, 'message' => 'Error Verifying User']);
      }
    } else {
      echo json_encode(['status' => 500, 'message' => 'NIN Verification Failed']);
    }
  } else {
    echo json_encode(['status' => 500, 'message' => 'Error uploading file']);
  }
}


function verifyNIN($document_nin) {
  $apiKey = 'sk_live_iqg2DK9sh8PYa7GUArlMVF7DGm8wNm5VaAO1qWjjKB89n8bhf6';
  $apiUrl = "https://v2.api.zeeh.africa/nigeria_kyc/lookup_nin";

  $curl = curl_init();

  curl_setopt_array($curl, [
    CURLOPT_URL => $apiUrl,
    CURLOPT_RETURNTRANSFER => true,
    CURLOPT_ENCODING => "",
    CURLOPT_MAXREDIRS => 10,
    CURLOPT_TIMEOUT => 30,
    CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
    CURLOPT_CUSTOMREQUEST => "POST",
    CURLOPT_POSTFIELDS => json_encode(['nin' =>  $document_nin]),
    //CURLOPT_POSTFIELDS => http_build_query(['nin' => $document_nin]), // Use http_build_query for simpler data format
    CURLOPT_HTTPHEADER => [
      "Secret_Key: $apiKey",
      "accept: application/json",
      "content-type: application/json"
    ],
  ]);

  $response = curl_exec($curl);
  curl_close($curl);

  $data = json_decode($response, true);

  return $data;
}

function updateUserProfile($userId, $document_nin, $imagePath, $verificationData) {
  global $pdo;
  $document_verified = 1;

  try {
    $sql = "UPDATE profiles SET document = :document, document_nin = :document_nin, document_verified = :document_verified, json_data = :json_data WHERE user_id = :userId";
    $stmt = $pdo->prepare($sql);

    $stmt->bindValue(':document', $imagePath);
    $stmt->bindValue(':document_nin', $document_nin);
    $stmt->bindValue(':document_verified', $document_verified);
    $stmt->bindValue(':json_data', json_encode($verificationData));
    $stmt->bindValue(':userId', $userId);

    if ($stmt->execute()) {
      return ['status' => 200, 'message' => 'User Identity Verified', 'data' => $data];
    } else {
      return ['status' => 500, 'message' => 'Error Verifying User'];
    }
  } catch (PDOException $e) {
    return ['status' => 500, 'message' => 'Error Verifying User: ' . $e->getMessage()];
  }
}

?>